<?php
namespace Dispute\Service;



/**
 * Manage Dispute data.
 * @author andre.fourie
 */
class Dispute extends \Dispute\DataBin\Dispute
{


	/**
	 * ExecuteAfter: Create.
	 * New dispute created, notifications be required.
	 * @param array $meta
	 * @param object|null $jobRecord
	 * @param object|null $record
	 * @param \Workspace\Utility\ServiceInputParams $contract
	 */
	public function sendDisputeNotification($meta, $jobRecord, $record, \Workspace\Utility\ServiceInputParams $contract)
	{
		#-> Collect.
		$vehicle = $record->auction->stock->type->model->make->name
				. ', ' . $record->auction->stock->type->model->name
				. ', ' . $record->auction->stock->type->name
				. ' (' . $record->auction->stock->vehicleYear->name . ')';
		$params = array(
						'vehicle' 				=> $vehicle,
						'complaint' 			=> $record->complaint,
						'plaintive' 			=> $record->fromCompany->name,
						'defendant' 			=> $record->againstCompany->name,
						'reference_number' 		=> $record->id,
						'registration_number' 	=> $record->auction->stock->registrationNumber,
						'plaintive_contact' 	=> $record->fromCompany->contact->firstName
						. ' ' . $record->fromCompany->contact->familyName,
						'plaintive_telephone' 	=> $record->fromCompany->contact->office,
						'plaintive_mobile' 		=> $record->fromCompany->contact->mobile,
						'plaintive_email' 		=> $record->fromCompany->contact->email,
						'defendant_contact' 	=> $record->againstCompany->contact->firstName
						. ' ' . $record->againstCompany->contact->familyName,
						'defendant_telephone' 	=> $record->againstCompany->contact->office,
						'defendant_mobile' 		=> $record->againstCompany->contact->mobile,
						'defendant_email' 		=> $record->againstCompany->contact->email
				);

		#-> Send.
		$oNotify = new \Utility\Comms\Notification();
		$oNotify->sendFromTemplate(
				$record->fromCompany->id, $record->createdBy->id,
				$record->fromCompany->id, $record->createdBy->id,
				$record->fromCompany->contact->email, null,
				null, 'new-dispute', $params
		);
		$oNotify->sendFromTemplate(
				$record->fromCompany->id, $record->createdBy->id,
				$record->againstCompany->id, null,
				$record->againstCompany->contact->email, null,
				null, 'new-dispute', $params
		);
		$oNotify->sendFromTemplate(
				$record->fromCompany->id, $record->createdBy->id,
				null, null,
				\Utility\Definitions\Locale::getAdminEmailAddress(), null,
				null, 'new-dispute', $params
		);
    $oNotify->sendFromTemplate(
				$record->fromCompany->id, $record->createdBy->id,
				null, null,
				'info@bid4cars.co.za', null,
				null, 'new-dispute', $params
		);
	}



}